/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_wmCOcu6S);
  numBytes += sLine_init(&sLine_G6ZbzoK3);
  numBytes += sLine_init(&sLine_G8OmWKmD);
  numBytes += sLine_init(&sLine_JYf4Hmbi);
  numBytes += sLine_init(&sLine_Kwgbw6KV);
  numBytes += sLine_init(&sLine_ZpME6rU0);
  numBytes += sLine_init(&sLine_xt9dHIij);
  numBytes += sLine_init(&sLine_Hp07ruxp);
  numBytes += sLine_init(&sLine_yaVQ2JfC);
  numBytes += sLine_init(&sLine_yx3HknVq);
  numBytes += sLine_init(&sLine_fYr3WKsE);
  numBytes += sLine_init(&sLine_lWXtAXxY);
  numBytes += sEnv_init(&sEnv_JDwHNMNY, 512, 256);
  numBytes += sEnv_init(&sEnv_VRKADSu0, 512, 256);
  numBytes += sLine_init(&sLine_FcCM9BTc);
  numBytes += sLine_init(&sLine_GDW0FGeo);
  numBytes += sLine_init(&sLine_UpQ2PGnF);
  numBytes += sLine_init(&sLine_ycdSuMC9);
  numBytes += sLine_init(&sLine_3vD6CxH1);
  numBytes += sLine_init(&sLine_pWEMR9Yu);
  numBytes += sLine_init(&sLine_0s2MJz6j);
  numBytes += sLine_init(&sLine_cKLaweRP);
  numBytes += sLine_init(&sLine_zbiQHFsm);
  numBytes += sLine_init(&sLine_bJfmdZuE);
  numBytes += sLine_init(&sLine_FbvuMgEX);
  numBytes += sLine_init(&sLine_1XwUNFHx);
  numBytes += sLine_init(&sLine_J0SMxXkp);
  numBytes += sLine_init(&sLine_O0aeQBam);
  numBytes += sLine_init(&sLine_OdotmxdX);
  numBytes += sLine_init(&sLine_5kFFWOvk);
  numBytes += sLine_init(&sLine_s1jJJEFI);
  numBytes += sLine_init(&sLine_rME2ynHy);
  numBytes += sEnv_init(&sEnv_Tvie4yfg, 512, 256);
  numBytes += sEnv_init(&sEnv_mld1hSEg, 512, 256);
  numBytes += sLine_init(&sLine_22iVh5e9);
  numBytes += sLine_init(&sLine_Wugx4BHv);
  numBytes += sLine_init(&sLine_86zybW2T);
  numBytes += sLine_init(&sLine_tTbunIRC);
  numBytes += sLine_init(&sLine_Tv70G0mE);
  numBytes += sLine_init(&sLine_xy5dMG1p);
  numBytes += sLine_init(&sLine_IuqT7Dzl);
  numBytes += sLine_init(&sLine_wOPXsQjY);
  numBytes += cVar_init_f(&cVar_FILEER27, 0.0f);
  numBytes += cVar_init_f(&cVar_vkTQMxFl, 0.0f);
  numBytes += cVar_init_f(&cVar_vSL6FdVZ, 0.0f);
  numBytes += cVar_init_f(&cVar_VcwyiKDl, 0.0f);
  numBytes += cVar_init_f(&cVar_bhsbnf00, 0.0f);
  numBytes += cVar_init_f(&cVar_XIAIrOA8, 1.0f);
  numBytes += cVar_init_f(&cVar_ZzTkccK7, 0.0f);
  numBytes += cVar_init_f(&cVar_X14XM7Cm, 0.0f);
  numBytes += cIf_init(&cIf_7p9dxONf, false);
  numBytes += cIf_init(&cIf_RnXxKfwe, false);
  numBytes += cDelay_init(this, &cDelay_giQpvPUe, 10.0f);
  numBytes += cIf_init(&cIf_utygVKID, false);
  numBytes += cIf_init(&cIf_0MrqPJIO, false);
  numBytes += cDelay_init(this, &cDelay_OHrqnorz, 10.0f);
  numBytes += cIf_init(&cIf_xKFNsWou, false);
  numBytes += cIf_init(&cIf_JNIaY379, false);
  numBytes += cDelay_init(this, &cDelay_8MbdLMR0, 10.0f);
  numBytes += cIf_init(&cIf_171D5TwJ, false);
  numBytes += cIf_init(&cIf_HkpqRy0F, false);
  numBytes += cDelay_init(this, &cDelay_ecrisSu9, 10.0f);
  numBytes += cIf_init(&cIf_OtksvVlz, false);
  numBytes += cIf_init(&cIf_sUcSdVVe, false);
  numBytes += cDelay_init(this, &cDelay_Rz6ctLaV, 10.0f);
  numBytes += cIf_init(&cIf_ZtrfhrUf, false);
  numBytes += cIf_init(&cIf_DsaNWxJm, false);
  numBytes += cDelay_init(this, &cDelay_4zpxZ7YI, 10.0f);
  numBytes += cIf_init(&cIf_VAsRcFp4, false);
  numBytes += cIf_init(&cIf_JJhVZGrX, false);
  numBytes += cDelay_init(this, &cDelay_4xWczBP2, 10.0f);
  numBytes += cIf_init(&cIf_BiSrR3sD, false);
  numBytes += cIf_init(&cIf_7awJdOMQ, false);
  numBytes += cDelay_init(this, &cDelay_UmBqlLwL, 10.0f);
  numBytes += cIf_init(&cIf_CWhikda7, false);
  numBytes += cIf_init(&cIf_qlgvcwlo, false);
  numBytes += cDelay_init(this, &cDelay_1b1dWPDU, 10.0f);
  numBytes += cIf_init(&cIf_MKqT23ZL, false);
  numBytes += cIf_init(&cIf_LE6PK7IK, false);
  numBytes += cDelay_init(this, &cDelay_a0UjGjZ6, 10.0f);
  numBytes += cIf_init(&cIf_anTvy62S, false);
  numBytes += cIf_init(&cIf_A1cs67gP, false);
  numBytes += cDelay_init(this, &cDelay_Z5ZgmNa3, 10.0f);
  numBytes += cIf_init(&cIf_JHaltQta, false);
  numBytes += cIf_init(&cIf_J0qYLxqJ, false);
  numBytes += cDelay_init(this, &cDelay_8i176ltb, 10.0f);
  numBytes += sVarf_init(&sVarf_o3oneHDx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p1VhzomV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BkRz0grt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i4ZBAD10, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kw1S0cir, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X5I32A2r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_awv28CFY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XmPQ737y, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_v1B6ORfG, 0.0f);
  numBytes += cSlice_init(&cSlice_HnhranM7, 1, -1);
  numBytes += cVar_init_f(&cVar_floQ4aih, 1.0f);
  numBytes += cSlice_init(&cSlice_XgqueOPA, 1, -1);
  numBytes += cVar_init_f(&cVar_nh2AXAfL, 0.0f);
  numBytes += cSlice_init(&cSlice_x6yweMIB, 1, -1);
  numBytes += cVar_init_f(&cVar_kqYlqubX, 512.0f);
  numBytes += cSlice_init(&cSlice_mlY9pOjm, 1, -1);
  numBytes += cVar_init_f(&cVar_alO1u5Wb, 1.0f);
  numBytes += cSlice_init(&cSlice_g07UWOPz, 1, -1);
  numBytes += cVar_init_f(&cVar_PQ5FoBOa, 1.0f);
  numBytes += cDelay_init(this, &cDelay_8OlgsBJI, 20.0f);
  numBytes += cVar_init_f(&cVar_uZ5zofze, 0.0f);
  numBytes += cIf_init(&cIf_nCX10vqh, false);
  numBytes += cIf_init(&cIf_Oif68nsI, false);
  numBytes += cBinop_init(&cBinop_XElwT3Zx, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_DvOt2Bq3, 1, -1);
  numBytes += cVar_init_f(&cVar_jvA5t7fD, 0.0f);
  numBytes += sVarf_init(&sVarf_TacSYhKK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aprOSxP5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RnXA957c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_45NEmqCM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GQEFa04T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SOfePqhU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IAsubOND, 0.0f);
  numBytes += cVar_init_f(&cVar_l5IG4b19, 0.0f);
  numBytes += cIf_init(&cIf_bwvGGO2j, false);
  numBytes += cIf_init(&cIf_ABgoCBCY, false);
  numBytes += cDelay_init(this, &cDelay_EpfMo0fD, 10.0f);
  numBytes += cIf_init(&cIf_cLSfsJt4, false);
  numBytes += cIf_init(&cIf_UnVxNRBp, false);
  numBytes += cDelay_init(this, &cDelay_P2i9UCEy, 10.0f);
  numBytes += cIf_init(&cIf_B4mMczXR, false);
  numBytes += cIf_init(&cIf_sviWSIaz, false);
  numBytes += cDelay_init(this, &cDelay_Bvz6xtwH, 10.0f);
  numBytes += cIf_init(&cIf_MNB1pAHF, false);
  numBytes += cIf_init(&cIf_kSug9LIE, false);
  numBytes += cDelay_init(this, &cDelay_LREdwuJZ, 10.0f);
  numBytes += cIf_init(&cIf_XqE8ExpJ, false);
  numBytes += cIf_init(&cIf_pWzClJO2, false);
  numBytes += cDelay_init(this, &cDelay_ECFqWwsH, 10.0f);
  numBytes += cIf_init(&cIf_Hv7fPeQO, false);
  numBytes += cIf_init(&cIf_EjFkYxbq, false);
  numBytes += cDelay_init(this, &cDelay_0Qll7edR, 10.0f);
  numBytes += cIf_init(&cIf_39EUw7bN, false);
  numBytes += cIf_init(&cIf_TN7aTUmb, false);
  numBytes += cDelay_init(this, &cDelay_5PfQihog, 10.0f);
  numBytes += cIf_init(&cIf_QTJYTR6v, false);
  numBytes += cIf_init(&cIf_6wyqfr58, false);
  numBytes += cDelay_init(this, &cDelay_zEUpFHLb, 10.0f);
  numBytes += cIf_init(&cIf_f07mrmbn, false);
  numBytes += cIf_init(&cIf_Eqss9iqV, false);
  numBytes += cDelay_init(this, &cDelay_sZU634PT, 10.0f);
  numBytes += cIf_init(&cIf_vdgGWCgm, false);
  numBytes += cIf_init(&cIf_6rVvHcYW, false);
  numBytes += cDelay_init(this, &cDelay_ieFyHEKQ, 10.0f);
  numBytes += cIf_init(&cIf_YbTwMrTU, false);
  numBytes += cIf_init(&cIf_jHUnmDaA, false);
  numBytes += cDelay_init(this, &cDelay_uJzC7HwE, 10.0f);
  numBytes += cIf_init(&cIf_mQ5SVYHI, false);
  numBytes += cIf_init(&cIf_77ywp9IQ, false);
  numBytes += cDelay_init(this, &cDelay_EWG99OGM, 10.0f);
  numBytes += sVarf_init(&sVarf_DynOA7fD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nAtyG6mw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cD94kfdg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kEnnEvKk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5eaTzBVA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RYj0ub4c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rm9RCCfZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UDzmW5bE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_9q1vISqU, 0.0f);
  numBytes += cSlice_init(&cSlice_mFCybzCO, 1, -1);
  numBytes += cVar_init_f(&cVar_o02SDF25, 1.0f);
  numBytes += cSlice_init(&cSlice_9Rf1i4RH, 1, -1);
  numBytes += cVar_init_f(&cVar_sqJyWLnc, 0.0f);
  numBytes += cSlice_init(&cSlice_5R8H2iTJ, 1, -1);
  numBytes += cVar_init_f(&cVar_MbuRkZgG, 512.0f);
  numBytes += cSlice_init(&cSlice_0UzxvfV8, 1, -1);
  numBytes += cVar_init_f(&cVar_cBXzkei5, 1.0f);
  numBytes += cSlice_init(&cSlice_k8iYyJkT, 1, -1);
  numBytes += cVar_init_f(&cVar_RLKvMPDk, 1.0f);
  numBytes += cDelay_init(this, &cDelay_UFk7OQCd, 20.0f);
  numBytes += cVar_init_f(&cVar_nYNuWklT, 0.0f);
  numBytes += cIf_init(&cIf_FVOTqAue, false);
  numBytes += cIf_init(&cIf_JlbDpeBV, false);
  numBytes += cBinop_init(&cBinop_PGPSR4UE, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_via48rDx, 1, -1);
  numBytes += cVar_init_f(&cVar_tOAfw3pF, 0.0f);
  numBytes += sVarf_init(&sVarf_S3AkB2RD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yZuo3UrK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M8Al2XO4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GkdFrnHa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bMmlPSJI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Hai6c2bq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0lnzTmgD, 0.0f);
  numBytes += sVarf_init(&sVarf_VlEFe1js, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zuNkJuKm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RhrlLAm7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1n2B06fd, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_JDwHNMNY);
  sEnv_free(&sEnv_VRKADSu0);
  sEnv_free(&sEnv_Tvie4yfg);
  sEnv_free(&sEnv_mld1hSEg);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q5H7kLLC_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ej10agL8_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4RwcJkzx_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_83KrHcjq_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_grDDEPIO_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ONynpHoe_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hk3aMEWQ_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HDMLS65V_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BYdby8Lg_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xBn5amjx_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tMRU8C6D_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aEwB1SCF_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JGTzcU4D_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LtJrdcA4_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_knFxVZcx_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_85lRXceF_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UbS9DjyP_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1bGDn5Y1_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HdLDbw1M_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PpDpiPfp_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pPBqkwW3_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_FILEER27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ortsobrh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_AoApYenF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ViSdWbZH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ViSdWbZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_f56WHq78_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_f56WHq78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kPt9fYWP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kPt9fYWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_diUbFKiy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_decwhI83_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_decwhI83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hH9A7BwB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_diUbFKiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_m2YocteW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_m2YocteW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kDNSLlr7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hH9A7BwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tlU7gokm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tlU7gokm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MavXnrjW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kDNSLlr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qfivXNq2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_MavXnrjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ybtthN8P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_vkTQMxFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ApJsM8LP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_vSL6FdVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W31QjjCg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_VcwyiKDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BcHgdzb7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_bhsbnf00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iTTHGR1B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_XIAIrOA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wlTZFQ1D_sendMessage);
  cMsg_K2HvwISw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_wlTZFQ1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XIAIrOA8, 1, m, &cVar_XIAIrOA8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KziU9c65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9eG2hl5j_sendMessage(_c, 0, m);
  cMsg_XCD5N96f_sendMessage(_c, 0, m);
  cMsg_1GQNTgRn_sendMessage(_c, 0, m);
  cMsg_xAiJ7SPk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_ZzTkccK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iWatoLdn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_X14XM7Cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5eXrerjl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ndqJPa5s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0qxtuz0t_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KNdOSuC8_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JzJCcjkz_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fvP6sEOj_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JzOXT88T_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v9st3sPf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_0qxtuz0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dWmiOFeD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_KNdOSuC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9AiWcJom_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_JzJCcjkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GVCkBntn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_fvP6sEOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Rn9ceQJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_JzOXT88T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_84s5kSCn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_v9st3sPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XHha9337_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_7p9dxONf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_52b9DN54_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_RnXxKfwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6Im20Mex_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_uExHmsAw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4P4XWs9x_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4P4XWs9x_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_giQpvPUe, 1, m, &cDelay_giQpvPUe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ui45UBAI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_giQpvPUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_giQpvPUe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7p9dxONf, 0, m, &cIf_7p9dxONf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4P4XWs9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_giQpvPUe, 0, m, &cDelay_giQpvPUe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ui45UBAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_giQpvPUe, 0, m, &cDelay_giQpvPUe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_9bStXcLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XR3VGoP0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w1t9QjMt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_9HSdizdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_klvir7f3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cd9x250f_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cd9x250f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uExHmsAw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_klvir7f3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7p9dxONf, 1, m, &cIf_7p9dxONf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_w1t9QjMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RnXxKfwe, 0, m, &cIf_RnXxKfwe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XR3VGoP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RnXxKfwe, 1, m, &cIf_RnXxKfwe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6Im20Mex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JYf4Hmbi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_52b9DN54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JYf4Hmbi, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_utygVKID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_P1h7rPHG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_0MrqPJIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5sMbcDy2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5vkOmsPk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kRdyttWF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kRdyttWF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OHrqnorz, 1, m, &cDelay_OHrqnorz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uqQyyZz2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_OHrqnorz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OHrqnorz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_utygVKID, 0, m, &cIf_utygVKID_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kRdyttWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OHrqnorz, 0, m, &cDelay_OHrqnorz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uqQyyZz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OHrqnorz, 0, m, &cDelay_OHrqnorz_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KL9Qq1AH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fniDEMr5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TQzr31Gc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ZF8hbBxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_piDGIhUb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eqbpusxe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eqbpusxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5vkOmsPk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_piDGIhUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_utygVKID, 1, m, &cIf_utygVKID_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fniDEMr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0MrqPJIO, 1, m, &cIf_0MrqPJIO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TQzr31Gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0MrqPJIO, 0, m, &cIf_0MrqPJIO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5sMbcDy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xt9dHIij, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_P1h7rPHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xt9dHIij, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xKFNsWou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Jt7Bp1Y5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_JNIaY379_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Cwnm57j2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ONOwBJDx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Jcm1VBFu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Jcm1VBFu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8MbdLMR0, 1, m, &cDelay_8MbdLMR0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_y6muCfYH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8MbdLMR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8MbdLMR0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xKFNsWou, 0, m, &cIf_xKFNsWou_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Jcm1VBFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8MbdLMR0, 0, m, &cDelay_8MbdLMR0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_y6muCfYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8MbdLMR0, 0, m, &cDelay_8MbdLMR0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3ukOEQ3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZaA45SM6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7W7dNbNv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PsCRqoz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p8i3E3I5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V5XEO0x2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_V5XEO0x2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ONOwBJDx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_p8i3E3I5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xKFNsWou, 1, m, &cIf_xKFNsWou_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZaA45SM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JNIaY379, 1, m, &cIf_JNIaY379_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7W7dNbNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JNIaY379, 0, m, &cIf_JNIaY379_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Cwnm57j2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yx3HknVq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Jt7Bp1Y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yx3HknVq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_171D5TwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_byQCOnTJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_HkpqRy0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LPjYigYX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_YFpFcAm4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9bRL6kPV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9bRL6kPV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ecrisSu9, 1, m, &cDelay_ecrisSu9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y25Qfls7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ecrisSu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ecrisSu9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_171D5TwJ, 0, m, &cIf_171D5TwJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9bRL6kPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ecrisSu9, 0, m, &cDelay_ecrisSu9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Y25Qfls7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ecrisSu9, 0, m, &cDelay_ecrisSu9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cRdmZ32D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Pn7t2O4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zK8mdOGK_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_phhO0Q21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QvMxFhcY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MvHZzjLK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QvMxFhcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_171D5TwJ, 1, m, &cIf_171D5TwJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MvHZzjLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YFpFcAm4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zK8mdOGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HkpqRy0F, 0, m, &cIf_HkpqRy0F_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7Pn7t2O4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HkpqRy0F, 1, m, &cIf_HkpqRy0F_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LPjYigYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kwgbw6KV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_byQCOnTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Kwgbw6KV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_OtksvVlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_souPN1bf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_sUcSdVVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eNM2adwG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Sjq76s1y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KYKCSPVh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KYKCSPVh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Rz6ctLaV, 1, m, &cDelay_Rz6ctLaV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tpaZvxBP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Rz6ctLaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Rz6ctLaV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OtksvVlz, 0, m, &cIf_OtksvVlz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KYKCSPVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rz6ctLaV, 0, m, &cDelay_Rz6ctLaV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tpaZvxBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rz6ctLaV, 0, m, &cDelay_Rz6ctLaV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1Xxkvqpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nyeNjlwZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_siPLe0nx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_SlK5v7Ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jFCDI0em_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nWkpicDu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jFCDI0em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OtksvVlz, 1, m, &cIf_OtksvVlz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nWkpicDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Sjq76s1y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_nyeNjlwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sUcSdVVe, 1, m, &cIf_sUcSdVVe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_siPLe0nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sUcSdVVe, 0, m, &cIf_sUcSdVVe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eNM2adwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hp07ruxp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_souPN1bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hp07ruxp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ZtrfhrUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_krvoC3BE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DsaNWxJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9sxU7zEs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_xGEA6dmx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UAId4ZaR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UAId4ZaR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4zpxZ7YI, 1, m, &cDelay_4zpxZ7YI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pP77a2Lw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_4zpxZ7YI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4zpxZ7YI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZtrfhrUf, 0, m, &cIf_ZtrfhrUf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UAId4ZaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4zpxZ7YI, 0, m, &cDelay_4zpxZ7YI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pP77a2Lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4zpxZ7YI, 0, m, &cDelay_4zpxZ7YI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Wqmp3Sas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pcAwsSNP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dy4InfrS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iX4MNBpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hUfmPn6t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tIwVU1KL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tIwVU1KL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xGEA6dmx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hUfmPn6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZtrfhrUf, 1, m, &cIf_ZtrfhrUf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pcAwsSNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DsaNWxJm, 1, m, &cIf_DsaNWxJm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dy4InfrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DsaNWxJm, 0, m, &cIf_DsaNWxJm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9sxU7zEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fYr3WKsE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_krvoC3BE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fYr3WKsE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_VAsRcFp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PJH7A29f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_JJhVZGrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GUSbTBqq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_j2rIM6gJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1QcsC8YK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1QcsC8YK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4xWczBP2, 1, m, &cDelay_4xWczBP2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4OAuNYo5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_4xWczBP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4xWczBP2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VAsRcFp4, 0, m, &cIf_VAsRcFp4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1QcsC8YK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4xWczBP2, 0, m, &cDelay_4xWczBP2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4OAuNYo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4xWczBP2, 0, m, &cDelay_4xWczBP2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aRovM1Sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VmlUbxiO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PafTBHAb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cEVFpwi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OnASp9ux_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kTMcoiD1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kTMcoiD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_j2rIM6gJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OnASp9ux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VAsRcFp4, 1, m, &cIf_VAsRcFp4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VmlUbxiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JJhVZGrX, 1, m, &cIf_JJhVZGrX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PafTBHAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JJhVZGrX, 0, m, &cIf_JJhVZGrX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GUSbTBqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZpME6rU0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_PJH7A29f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZpME6rU0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_BiSrR3sD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7hlPeN01_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7awJdOMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BZyCuiqd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_0wIM0w1h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9BmPEvMt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9BmPEvMt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UmBqlLwL, 1, m, &cDelay_UmBqlLwL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5n8iQHLd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_UmBqlLwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UmBqlLwL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BiSrR3sD, 0, m, &cIf_BiSrR3sD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9BmPEvMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UmBqlLwL, 0, m, &cDelay_UmBqlLwL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5n8iQHLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UmBqlLwL, 0, m, &cDelay_UmBqlLwL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_83AiBWYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AmsMxKbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UkiChCt1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fge9ewtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D6DXfwnz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bine5MVC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Bine5MVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0wIM0w1h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_D6DXfwnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BiSrR3sD, 1, m, &cIf_BiSrR3sD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UkiChCt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7awJdOMQ, 0, m, &cIf_7awJdOMQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AmsMxKbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7awJdOMQ, 1, m, &cIf_7awJdOMQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BZyCuiqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yaVQ2JfC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7hlPeN01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yaVQ2JfC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_CWhikda7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w1hTFn5W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_qlgvcwlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LqQ1T3E7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_zeZeNbDT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pPnxBufG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pPnxBufG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1b1dWPDU, 1, m, &cDelay_1b1dWPDU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2fx3edPQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_1b1dWPDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1b1dWPDU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CWhikda7, 0, m, &cIf_CWhikda7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pPnxBufG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1b1dWPDU, 0, m, &cDelay_1b1dWPDU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2fx3edPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1b1dWPDU, 0, m, &cDelay_1b1dWPDU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7cvjTWYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GrDnfxi7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EetXUoJ6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Vu4VC3r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CTwFR0M4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dAKdSUhF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dAKdSUhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zeZeNbDT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_CTwFR0M4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CWhikda7, 1, m, &cIf_CWhikda7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GrDnfxi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qlgvcwlo, 1, m, &cIf_qlgvcwlo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EetXUoJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qlgvcwlo, 0, m, &cIf_qlgvcwlo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LqQ1T3E7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lWXtAXxY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_w1hTFn5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lWXtAXxY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_MKqT23ZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NgxQx7UL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_LE6PK7IK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OkwD57Ep_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_obSWAr2X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Sc4rEV5O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Sc4rEV5O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_a0UjGjZ6, 1, m, &cDelay_a0UjGjZ6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WCKMFdz7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_a0UjGjZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a0UjGjZ6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MKqT23ZL, 0, m, &cIf_MKqT23ZL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Sc4rEV5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_a0UjGjZ6, 0, m, &cDelay_a0UjGjZ6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WCKMFdz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_a0UjGjZ6, 0, m, &cDelay_a0UjGjZ6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RxeFnQSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UAiodedJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_807MrEIc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_I7lP9ZGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aS7wr2s7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7oNrd6QF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7oNrd6QF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_obSWAr2X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_aS7wr2s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKqT23ZL, 1, m, &cIf_MKqT23ZL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UAiodedJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LE6PK7IK, 1, m, &cIf_LE6PK7IK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_807MrEIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LE6PK7IK, 0, m, &cIf_LE6PK7IK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OkwD57Ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wmCOcu6S, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NgxQx7UL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wmCOcu6S, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_anTvy62S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mU2CQVb3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_A1cs67gP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3gv4mRGh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_hlYfwfYT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0uECIGJ0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0uECIGJ0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Z5ZgmNa3, 1, m, &cDelay_Z5ZgmNa3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_41Lg3Zmd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Z5ZgmNa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Z5ZgmNa3, m);
  cIf_onMessage(_c, &Context(_c)->cIf_anTvy62S, 0, m, &cIf_anTvy62S_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0uECIGJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z5ZgmNa3, 0, m, &cDelay_Z5ZgmNa3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_41Lg3Zmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z5ZgmNa3, 0, m, &cDelay_Z5ZgmNa3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MICq0aKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5YinI6Mj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1WEXrHBS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_B3skGON6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sjR3tPac_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gc87SygD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Gc87SygD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hlYfwfYT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_sjR3tPac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_anTvy62S, 1, m, &cIf_anTvy62S_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1WEXrHBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A1cs67gP, 0, m, &cIf_A1cs67gP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5YinI6Mj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A1cs67gP, 1, m, &cIf_A1cs67gP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3gv4mRGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G6ZbzoK3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_mU2CQVb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G6ZbzoK3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_JHaltQta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q1RgbJEp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_J0qYLxqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ATdh6TnO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_95ORMhlz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZVBZyrFg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZVBZyrFg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8i176ltb, 1, m, &cDelay_8i176ltb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_76J3n61s_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8i176ltb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8i176ltb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JHaltQta, 0, m, &cIf_JHaltQta_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZVBZyrFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8i176ltb, 0, m, &cDelay_8i176ltb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_76J3n61s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8i176ltb, 0, m, &cDelay_8i176ltb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UM20N5Ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bl6bjD4p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OlEiZ2l5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EvRnekNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bThv6gST_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jAMFjg4S_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bThv6gST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JHaltQta, 1, m, &cIf_JHaltQta_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jAMFjg4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_95ORMhlz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Bl6bjD4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J0qYLxqJ, 1, m, &cIf_J0qYLxqJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OlEiZ2l5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J0qYLxqJ, 0, m, &cIf_J0qYLxqJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ATdh6TnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G8OmWKmD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Q1RgbJEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G8OmWKmD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_dWmiOFeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_SiHH8f7H_sendMessage(_c, 0, m);
  cMsg_rSYj3lRs_sendMessage(_c, 0, m);
  cMsg_69aHRofr_sendMessage(_c, 0, m);
  cMsg_sMrM0KGF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9AiWcJom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_SiHH8f7H_sendMessage(_c, 0, m);
  cMsg_yNSAJ8OW_sendMessage(_c, 0, m);
  cMsg_1bmOv71y_sendMessage(_c, 0, m);
  cMsg_0yoqaODW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_GVCkBntn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_xrdBs0J6_sendMessage(_c, 0, m);
  cMsg_yNSAJ8OW_sendMessage(_c, 0, m);
  cMsg_sMrM0KGF_sendMessage(_c, 0, m);
  cMsg_UiLZGhFB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0Rn9ceQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_xrdBs0J6_sendMessage(_c, 0, m);
  cMsg_eS32vgU9_sendMessage(_c, 0, m);
  cMsg_69aHRofr_sendMessage(_c, 0, m);
  cMsg_1c9dKUFg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_84s5kSCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_bpy7bBUC_sendMessage(_c, 0, m);
  cMsg_0yoqaODW_sendMessage(_c, 0, m);
  cMsg_uDGNKW2R_sendMessage(_c, 0, m);
  cMsg_69aHRofr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XHha9337_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_bpy7bBUC_sendMessage(_c, 0, m);
  cMsg_1c9dKUFg_sendMessage(_c, 0, m);
  cMsg_yNSAJ8OW_sendMessage(_c, 0, m);
  cMsg_tqKhFTy8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cYEy3aDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9HSdizdT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9bStXcLd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ow8cHwKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9HSdizdT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9bStXcLd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_g1GmQ8uL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZF8hbBxx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KL9Qq1AH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_v0Um5TKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZF8hbBxx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KL9Qq1AH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dzjsylmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PsCRqoz1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3ukOEQ3M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kJGCqrCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PsCRqoz1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3ukOEQ3M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SiHH8f7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_cYEy3aDm_sendMessage(_c, 0, m);
  cMsg_v0Um5TKK_sendMessage(_c, 0, m);
  cMsg_kJGCqrCu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xrdBs0J6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ow8cHwKC_sendMessage(_c, 0, m);
  cMsg_g1GmQ8uL_sendMessage(_c, 0, m);
  cMsg_kJGCqrCu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bpy7bBUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ow8cHwKC_sendMessage(_c, 0, m);
  cMsg_v0Um5TKK_sendMessage(_c, 0, m);
  cMsg_dzjsylmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_uC0e5hxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_phhO0Q21_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cRdmZ32D_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Pa0k0TI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_phhO0Q21_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cRdmZ32D_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1dWoBr9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SlK5v7Ik_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1Xxkvqpq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vrF3KM3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SlK5v7Ik_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1Xxkvqpq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NktFX1vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iX4MNBpU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Wqmp3Sas_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jTdW1Nk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iX4MNBpU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Wqmp3Sas_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yNSAJ8OW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Pa0k0TI7_sendMessage(_c, 0, m);
  cMsg_vrF3KM3S_sendMessage(_c, 0, m);
  cMsg_jTdW1Nk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rSYj3lRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Pa0k0TI7_sendMessage(_c, 0, m);
  cMsg_1dWoBr9l_sendMessage(_c, 0, m);
  cMsg_NktFX1vB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eS32vgU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_uC0e5hxm_sendMessage(_c, 0, m);
  cMsg_vrF3KM3S_sendMessage(_c, 0, m);
  cMsg_NktFX1vB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_U53ODIuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I7lP9ZGW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RxeFnQSG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_U8RUCyOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_I7lP9ZGW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RxeFnQSG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BDAciwym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B3skGON6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MICq0aKP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_K3kJxNkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B3skGON6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MICq0aKP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1SafpEDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EvRnekNa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UM20N5Ap_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mMIPeN2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EvRnekNa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UM20N5Ap_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1c9dKUFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_U53ODIuN_sendMessage(_c, 0, m);
  cMsg_K3kJxNkG_sendMessage(_c, 0, m);
  cMsg_mMIPeN2O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0yoqaODW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_U8RUCyOX_sendMessage(_c, 0, m);
  cMsg_BDAciwym_sendMessage(_c, 0, m);
  cMsg_mMIPeN2O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sMrM0KGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_U8RUCyOX_sendMessage(_c, 0, m);
  cMsg_K3kJxNkG_sendMessage(_c, 0, m);
  cMsg_1SafpEDp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4Vk5zms2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cEVFpwi2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aRovM1Sm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_doHzZS4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cEVFpwi2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aRovM1Sm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zotdDBt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fge9ewtU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_83AiBWYP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PNcAy5Ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fge9ewtU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_83AiBWYP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_juXT0Lei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vu4VC3r7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7cvjTWYi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9clyhIFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vu4VC3r7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7cvjTWYi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_69aHRofr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_doHzZS4T_sendMessage(_c, 0, m);
  cMsg_PNcAy5Ln_sendMessage(_c, 0, m);
  cMsg_9clyhIFO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_1bmOv71y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_doHzZS4T_sendMessage(_c, 0, m);
  cMsg_zotdDBt5_sendMessage(_c, 0, m);
  cMsg_juXT0Lei_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_tqKhFTy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_4Vk5zms2_sendMessage(_c, 0, m);
  cMsg_zotdDBt5_sendMessage(_c, 0, m);
  cMsg_9clyhIFO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_uDGNKW2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_uC0e5hxm_sendMessage(_c, 0, m);
  cMsg_1dWoBr9l_sendMessage(_c, 0, m);
  cMsg_jTdW1Nk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_UiLZGhFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_4Vk5zms2_sendMessage(_c, 0, m);
  cMsg_PNcAy5Ln_sendMessage(_c, 0, m);
  cMsg_juXT0Lei_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_v1B6ORfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GPBPJJ3X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_IGsdhpnA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HnhranM7, 0, m, &cSlice_HnhranM7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RO9ddydy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_HnhranM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MpjBRVTg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MpjBRVTg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_floQ4aih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MpjBRVTg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_MpjBRVTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xBn5amjx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_97A4sH9I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XgqueOPA, 0, m, &cSlice_XgqueOPA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vymAF5KY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_XgqueOPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aQa0ShWm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aQa0ShWm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_nh2AXAfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aQa0ShWm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_aQa0ShWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LtJrdcA4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_vymAF5KY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x6yweMIB, 0, m, &cSlice_x6yweMIB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IGsdhpnA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_x6yweMIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gJ8ewilK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gJ8ewilK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_kqYlqubX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gJ8ewilK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_gJ8ewilK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BYdby8Lg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_RO9ddydy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mlY9pOjm, 0, m, &cSlice_mlY9pOjm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rmytXYPp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_mlY9pOjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_I6F9NnGM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_I6F9NnGM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_alO1u5Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_I6F9NnGM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_I6F9NnGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JGTzcU4D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_rmytXYPp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g07UWOPz, 0, m, &cSlice_g07UWOPz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qnL6Hybs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_g07UWOPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IYYfPZzq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IYYfPZzq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_PQ5FoBOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IYYfPZzq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_IYYfPZzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aEwB1SCF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_BzzqyRmK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RZvdLdUR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RZvdLdUR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8OlgsBJI, 1, m, &cDelay_8OlgsBJI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cszJCD3n_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8OlgsBJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8OlgsBJI, m);
  cMsg_jRjdvNNT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RZvdLdUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8OlgsBJI, 0, m, &cDelay_8OlgsBJI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cszJCD3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8OlgsBJI, 0, m, &cDelay_8OlgsBJI_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_uZ5zofze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XElwT3Zx, HV_BINOP_SUBTRACT, 0, m, &cBinop_XElwT3Zx_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_nCX10vqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1a2nBkwG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Oif68nsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1a2nBkwG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_JDwHNMNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uZ5zofze, 0, m, &cVar_uZ5zofze_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_VRKADSu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jILex9fW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OKU95bYO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h8fgcywp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XElwT3Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VimSDSYi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_VimSDSYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gPlN9L33_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gPlN9L33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5bp1kTT5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aVfpPkbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2uRyNisH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u2cdZyUT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_u2cdZyUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FhSxY0YR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_2uRyNisH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nCX10vqh, 1, m, &cIf_nCX10vqh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_QrmtKUA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oif68nsI, 1, m, &cIf_Oif68nsI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FhSxY0YR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nCX10vqh, 0, m, &cIf_nCX10vqh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5bp1kTT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oif68nsI, 0, m, &cIf_Oif68nsI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_h8fgcywp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uZ5zofze, 0, m, &cVar_uZ5zofze_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OKU95bYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XElwT3Zx, HV_BINOP_SUBTRACT, 1, m, &cBinop_XElwT3Zx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jILex9fW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cMsg_1a2nBkwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FcCM9BTc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_qnL6Hybs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DvOt2Bq3, 0, m, &cSlice_DvOt2Bq3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_DvOt2Bq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UHqC9znu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UHqC9znu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_jvA5t7fD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UHqC9znu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_UHqC9znu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tMRU8C6D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_iWatoLdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pWEMR9Yu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_5eXrerjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ycdSuMC9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_u7WFN1SU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X14XM7Cm, 0, m, &cVar_X14XM7Cm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GPBPJJ3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3vD6CxH1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_okzJ7MOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i6lzUwbG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_wqBb2iQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BzzqyRmK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jRjdvNNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GDW0FGeo, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_i6lzUwbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GDW0FGeo, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_RImxlzrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_jsuRnnhQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jsuRnnhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WqNBoyiR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WqNBoyiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UpQ2PGnF, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_IAsubOND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0D4JO2L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_l5IG4b19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bJEFHdR7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_uweHJMOc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h4u6fvZL_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jr1XTE8v_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RyDDf0R4_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sZBX9N4E_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3kr2z769_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Uite2tcJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_h4u6fvZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EukgjRkb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_jr1XTE8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a0pQuYfW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_RyDDf0R4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TuRsBxpQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_sZBX9N4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sG1Kq2jv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_3kr2z769_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m7pBuD3X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Uite2tcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ar1mZxS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_bwvGGO2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yS9j2ZqF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ABgoCBCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g4ujinYR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_QW9UdARl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OyAkpjxl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OyAkpjxl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EpfMo0fD, 1, m, &cDelay_EpfMo0fD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HvgDufQA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_EpfMo0fD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EpfMo0fD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bwvGGO2j, 0, m, &cIf_bwvGGO2j_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OyAkpjxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EpfMo0fD, 0, m, &cDelay_EpfMo0fD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HvgDufQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EpfMo0fD, 0, m, &cDelay_EpfMo0fD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2u6aqVCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PYzEvQ52_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sQUaiTw6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eTVBW9iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R20vx9tz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3q8XDkbR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3q8XDkbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QW9UdARl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_R20vx9tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bwvGGO2j, 1, m, &cIf_bwvGGO2j_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PYzEvQ52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ABgoCBCY, 1, m, &cIf_ABgoCBCY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sQUaiTw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ABgoCBCY, 0, m, &cIf_ABgoCBCY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_g4ujinYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bJfmdZuE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yS9j2ZqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bJfmdZuE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_cLSfsJt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Od5Eu5DS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_UnVxNRBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9AejUwO6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_jfYdGqx8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_otWaeIeA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_otWaeIeA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_P2i9UCEy, 1, m, &cDelay_P2i9UCEy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1zrJXEol_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_P2i9UCEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_P2i9UCEy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cLSfsJt4, 0, m, &cIf_cLSfsJt4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_otWaeIeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2i9UCEy, 0, m, &cDelay_P2i9UCEy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1zrJXEol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_P2i9UCEy, 0, m, &cDelay_P2i9UCEy_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xtPRxyhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gOEDb3ST_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MPZEG3Ed_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_lwhz6UDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EdpSxcWj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_auqMTbKr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EdpSxcWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cLSfsJt4, 1, m, &cIf_cLSfsJt4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_auqMTbKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jfYdGqx8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_MPZEG3Ed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UnVxNRBp, 0, m, &cIf_UnVxNRBp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gOEDb3ST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UnVxNRBp, 1, m, &cIf_UnVxNRBp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9AejUwO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J0SMxXkp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Od5Eu5DS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J0SMxXkp, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_B4mMczXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Pbf5dvJy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_sviWSIaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wY7fDucr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_dlB7P7ui_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EoZDWOnL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EoZDWOnL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Bvz6xtwH, 1, m, &cDelay_Bvz6xtwH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KtL1xRdM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Bvz6xtwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Bvz6xtwH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_B4mMczXR, 0, m, &cIf_B4mMczXR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EoZDWOnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bvz6xtwH, 0, m, &cDelay_Bvz6xtwH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KtL1xRdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bvz6xtwH, 0, m, &cDelay_Bvz6xtwH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_WJx9q3n9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a71wA4JY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yjBKFnBU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gmZ5CWrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zSKumvsM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NfylotUA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NfylotUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dlB7P7ui_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zSKumvsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B4mMczXR, 1, m, &cIf_B4mMczXR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_a71wA4JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sviWSIaz, 1, m, &cIf_sviWSIaz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yjBKFnBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sviWSIaz, 0, m, &cIf_sviWSIaz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wY7fDucr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5kFFWOvk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Pbf5dvJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5kFFWOvk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_MNB1pAHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TEP7UMjv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_kSug9LIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wRjdaoHB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_eofg58ou_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tku86cBu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tku86cBu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LREdwuJZ, 1, m, &cDelay_LREdwuJZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CRbF4vUe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_LREdwuJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LREdwuJZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MNB1pAHF, 0, m, &cIf_MNB1pAHF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tku86cBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LREdwuJZ, 0, m, &cDelay_LREdwuJZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CRbF4vUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LREdwuJZ, 0, m, &cDelay_LREdwuJZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VmuICZlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UP2CiWnz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WiyezmkS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gbshdBHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s92ruojZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TWovkqca_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TWovkqca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eofg58ou_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_s92ruojZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MNB1pAHF, 1, m, &cIf_MNB1pAHF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WiyezmkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kSug9LIE, 0, m, &cIf_kSug9LIE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UP2CiWnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kSug9LIE, 1, m, &cIf_kSug9LIE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wRjdaoHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FbvuMgEX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_TEP7UMjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FbvuMgEX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_XqE8ExpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5Hr3UfdO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_pWzClJO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lHHKaBYB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_aD0ZDpx3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NJIWqcJe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NJIWqcJe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ECFqWwsH, 1, m, &cDelay_ECFqWwsH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ysTbzdgG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ECFqWwsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ECFqWwsH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XqE8ExpJ, 0, m, &cIf_XqE8ExpJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NJIWqcJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ECFqWwsH, 0, m, &cDelay_ECFqWwsH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ysTbzdgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ECFqWwsH, 0, m, &cDelay_ECFqWwsH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XdXrfw13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aH6aHogX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RBmxMhVn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2zHUvLS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OC7YXTma_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mJweaXWE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mJweaXWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aD0ZDpx3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OC7YXTma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XqE8ExpJ, 1, m, &cIf_XqE8ExpJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RBmxMhVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pWzClJO2, 0, m, &cIf_pWzClJO2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aH6aHogX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pWzClJO2, 1, m, &cIf_pWzClJO2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lHHKaBYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O0aeQBam, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_5Hr3UfdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O0aeQBam, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Hv7fPeQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qunKLB9A_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_EjFkYxbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9f0oVbmJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_dEVmwtZo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fDEHoKep_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fDEHoKep_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0Qll7edR, 1, m, &cDelay_0Qll7edR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nprBjDS1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_0Qll7edR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0Qll7edR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Hv7fPeQO, 0, m, &cIf_Hv7fPeQO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fDEHoKep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Qll7edR, 0, m, &cDelay_0Qll7edR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nprBjDS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Qll7edR, 0, m, &cDelay_0Qll7edR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oU0yc4Dy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xllqU0JB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NgJCYEQh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BmTZSVbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nPCl1C6o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mUIuFhZu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mUIuFhZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dEVmwtZo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_nPCl1C6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hv7fPeQO, 1, m, &cIf_Hv7fPeQO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xllqU0JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EjFkYxbq, 1, m, &cIf_EjFkYxbq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NgJCYEQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EjFkYxbq, 0, m, &cIf_EjFkYxbq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9f0oVbmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s1jJJEFI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_qunKLB9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s1jJJEFI, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_39EUw7bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wvz9lA0X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_TN7aTUmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xIMD208i_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_0Hl4JubC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xW4uM6mq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xW4uM6mq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5PfQihog, 1, m, &cDelay_5PfQihog_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R0D30Ew7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_5PfQihog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5PfQihog, m);
  cIf_onMessage(_c, &Context(_c)->cIf_39EUw7bN, 0, m, &cIf_39EUw7bN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xW4uM6mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5PfQihog, 0, m, &cDelay_5PfQihog_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_R0D30Ew7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5PfQihog, 0, m, &cDelay_5PfQihog_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2EQ5gegH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_493CF5zc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9PDStqaz_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Qti4BYmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tv6l8wRP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qKe5txkr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qKe5txkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0Hl4JubC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Tv6l8wRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_39EUw7bN, 1, m, &cIf_39EUw7bN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9PDStqaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TN7aTUmb, 0, m, &cIf_TN7aTUmb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_493CF5zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TN7aTUmb, 1, m, &cIf_TN7aTUmb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xIMD208i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1XwUNFHx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wvz9lA0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1XwUNFHx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_QTJYTR6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lBvF6rVr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_6wyqfr58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2M6kk6to_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_UwNXcBge_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WRfKllDL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WRfKllDL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zEUpFHLb, 1, m, &cDelay_zEUpFHLb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tYWmXijx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_zEUpFHLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zEUpFHLb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QTJYTR6v, 0, m, &cIf_QTJYTR6v_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WRfKllDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zEUpFHLb, 0, m, &cDelay_zEUpFHLb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tYWmXijx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zEUpFHLb, 0, m, &cDelay_zEUpFHLb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qWFnIlRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aT1PmXZR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C7ds1U8U_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rvFel35x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vnHzwDPR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rQYtMG8P_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rQYtMG8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UwNXcBge_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_vnHzwDPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QTJYTR6v, 1, m, &cIf_QTJYTR6v_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C7ds1U8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6wyqfr58, 0, m, &cIf_6wyqfr58_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aT1PmXZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6wyqfr58, 1, m, &cIf_6wyqfr58_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2M6kk6to_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OdotmxdX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lBvF6rVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OdotmxdX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_f07mrmbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nqWeLGpp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Eqss9iqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_INS5Txdr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_SMn5DbBY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Nf6fYd9R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Nf6fYd9R_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sZU634PT, 1, m, &cDelay_sZU634PT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OiiqN4qz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_sZU634PT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sZU634PT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_f07mrmbn, 0, m, &cIf_f07mrmbn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Nf6fYd9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sZU634PT, 0, m, &cDelay_sZU634PT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OiiqN4qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sZU634PT, 0, m, &cDelay_sZU634PT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_T8H28Wa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nl1COAG4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AYV4dE2R_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FI9BckWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s7WOh18f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bxptaol7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bxptaol7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SMn5DbBY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_s7WOh18f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f07mrmbn, 1, m, &cIf_f07mrmbn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AYV4dE2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Eqss9iqV, 0, m, &cIf_Eqss9iqV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nl1COAG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Eqss9iqV, 1, m, &cIf_Eqss9iqV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_INS5Txdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rME2ynHy, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nqWeLGpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rME2ynHy, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vdgGWCgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O8FENn3T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_6rVvHcYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CYPj2lYt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_uTVO2dgQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Iz2VKvkW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Iz2VKvkW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ieFyHEKQ, 1, m, &cDelay_ieFyHEKQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xcCIK5hf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ieFyHEKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ieFyHEKQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vdgGWCgm, 0, m, &cIf_vdgGWCgm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Iz2VKvkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ieFyHEKQ, 0, m, &cDelay_ieFyHEKQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xcCIK5hf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ieFyHEKQ, 0, m, &cDelay_ieFyHEKQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_y8AajBin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KU1ao1KI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ulaqsKTw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oJKQlnA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7CHamMNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7OLH2GSr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_7OLH2GSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uTVO2dgQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_7CHamMNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vdgGWCgm, 1, m, &cIf_vdgGWCgm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ulaqsKTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6rVvHcYW, 0, m, &cIf_6rVvHcYW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KU1ao1KI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6rVvHcYW, 1, m, &cIf_6rVvHcYW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CYPj2lYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0s2MJz6j, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_O8FENn3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0s2MJz6j, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_YbTwMrTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kBAkw6Xz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jHUnmDaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GjGEIAPx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_wj0aKpBY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Uzzs5DZP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Uzzs5DZP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uJzC7HwE, 1, m, &cDelay_uJzC7HwE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jvQDonC1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_uJzC7HwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uJzC7HwE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YbTwMrTU, 0, m, &cIf_YbTwMrTU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Uzzs5DZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uJzC7HwE, 0, m, &cDelay_uJzC7HwE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jvQDonC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uJzC7HwE, 0, m, &cDelay_uJzC7HwE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KLOkFwJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RQp1UPBa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CIdIvLSB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Wh8p2Q7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SsJQjxVC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IKYXCHn4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IKYXCHn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wj0aKpBY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_SsJQjxVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YbTwMrTU, 1, m, &cIf_YbTwMrTU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CIdIvLSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHUnmDaA, 0, m, &cIf_jHUnmDaA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RQp1UPBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHUnmDaA, 1, m, &cIf_jHUnmDaA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GjGEIAPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cKLaweRP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_kBAkw6Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cKLaweRP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_mQ5SVYHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JzbuWhMm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_77ywp9IQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lCFaG6sA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_8kasw5YF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CerlngH5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CerlngH5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EWG99OGM, 1, m, &cDelay_EWG99OGM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yyihfcH2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_EWG99OGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EWG99OGM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mQ5SVYHI, 0, m, &cIf_mQ5SVYHI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CerlngH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EWG99OGM, 0, m, &cDelay_EWG99OGM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yyihfcH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EWG99OGM, 0, m, &cDelay_EWG99OGM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fpnG3sWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RishZ3r6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X9LY2NBs_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EbEnw3YA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qRLmCok2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EEPB5Ud2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EEPB5Ud2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8kasw5YF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_qRLmCok2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mQ5SVYHI, 1, m, &cIf_mQ5SVYHI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_X9LY2NBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_77ywp9IQ, 0, m, &cIf_77ywp9IQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RishZ3r6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_77ywp9IQ, 1, m, &cIf_77ywp9IQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lCFaG6sA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zbiQHFsm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_JzbuWhMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zbiQHFsm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_EukgjRkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_XBR6A8me_sendMessage(_c, 0, m);
  cMsg_HzqnZ7qT_sendMessage(_c, 0, m);
  cMsg_8OqcM9n5_sendMessage(_c, 0, m);
  cMsg_1XxQGlOy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_a0pQuYfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_XBR6A8me_sendMessage(_c, 0, m);
  cMsg_V0j7rBUJ_sendMessage(_c, 0, m);
  cMsg_RH8EGPD7_sendMessage(_c, 0, m);
  cMsg_hHJGKlxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TuRsBxpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_fleUCnhG_sendMessage(_c, 0, m);
  cMsg_V0j7rBUJ_sendMessage(_c, 0, m);
  cMsg_1XxQGlOy_sendMessage(_c, 0, m);
  cMsg_DCdLwQhm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sG1Kq2jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_fleUCnhG_sendMessage(_c, 0, m);
  cMsg_kj47jlLt_sendMessage(_c, 0, m);
  cMsg_8OqcM9n5_sendMessage(_c, 0, m);
  cMsg_lamKeGLq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_m7pBuD3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_RnL24PQU_sendMessage(_c, 0, m);
  cMsg_hHJGKlxx_sendMessage(_c, 0, m);
  cMsg_2fyRLJIm_sendMessage(_c, 0, m);
  cMsg_8OqcM9n5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_3ar1mZxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_RnL24PQU_sendMessage(_c, 0, m);
  cMsg_lamKeGLq_sendMessage(_c, 0, m);
  cMsg_V0j7rBUJ_sendMessage(_c, 0, m);
  cMsg_CNzbk27o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_yFGUEgq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eTVBW9iQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2u6aqVCL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RBYTUs9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eTVBW9iQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2u6aqVCL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KQcTBA8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lwhz6UDx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xtPRxyhl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EDqfttKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lwhz6UDx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xtPRxyhl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VhO9fdMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gmZ5CWrt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WJx9q3n9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5Mhqb9af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gmZ5CWrt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WJx9q3n9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XBR6A8me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_yFGUEgq2_sendMessage(_c, 0, m);
  cMsg_EDqfttKv_sendMessage(_c, 0, m);
  cMsg_5Mhqb9af_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fleUCnhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_RBYTUs9K_sendMessage(_c, 0, m);
  cMsg_KQcTBA8V_sendMessage(_c, 0, m);
  cMsg_5Mhqb9af_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RnL24PQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_RBYTUs9K_sendMessage(_c, 0, m);
  cMsg_EDqfttKv_sendMessage(_c, 0, m);
  cMsg_VhO9fdMl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_UDFqajRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gbshdBHD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VmuICZlD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BCmb9IWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gbshdBHD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VmuICZlD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JBO8v7jn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2zHUvLS4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XdXrfw13_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NW1JOuNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2zHUvLS4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XdXrfw13_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_L0uwneoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BmTZSVbc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oU0yc4Dy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_w32cCMDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BmTZSVbc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oU0yc4Dy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_V0j7rBUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_BCmb9IWK_sendMessage(_c, 0, m);
  cMsg_NW1JOuNB_sendMessage(_c, 0, m);
  cMsg_w32cCMDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HzqnZ7qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_BCmb9IWK_sendMessage(_c, 0, m);
  cMsg_JBO8v7jn_sendMessage(_c, 0, m);
  cMsg_L0uwneoZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kj47jlLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_UDFqajRE_sendMessage(_c, 0, m);
  cMsg_NW1JOuNB_sendMessage(_c, 0, m);
  cMsg_L0uwneoZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bG5xdBp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oJKQlnA8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y8AajBin_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XBzfoLgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oJKQlnA8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y8AajBin_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AgDOzJ6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Wh8p2Q7k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KLOkFwJb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lNoNX2kB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Wh8p2Q7k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KLOkFwJb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XzoiUFHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EbEnw3YA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fpnG3sWz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_73SuZqgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EbEnw3YA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fpnG3sWz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lamKeGLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_bG5xdBp0_sendMessage(_c, 0, m);
  cMsg_lNoNX2kB_sendMessage(_c, 0, m);
  cMsg_73SuZqgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hHJGKlxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_XBzfoLgk_sendMessage(_c, 0, m);
  cMsg_AgDOzJ6s_sendMessage(_c, 0, m);
  cMsg_73SuZqgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_1XxQGlOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_XBzfoLgk_sendMessage(_c, 0, m);
  cMsg_lNoNX2kB_sendMessage(_c, 0, m);
  cMsg_XzoiUFHw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4vCIatMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qti4BYmU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2EQ5gegH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WHaTkLFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qti4BYmU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2EQ5gegH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_r1y85jeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rvFel35x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qWFnIlRm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tVNfKM6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rvFel35x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qWFnIlRm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZEsqiNqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FI9BckWE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T8H28Wa6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7of6Kna6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FI9BckWE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T8H28Wa6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8OqcM9n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_WHaTkLFI_sendMessage(_c, 0, m);
  cMsg_tVNfKM6i_sendMessage(_c, 0, m);
  cMsg_7of6Kna6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RH8EGPD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_WHaTkLFI_sendMessage(_c, 0, m);
  cMsg_r1y85jeE_sendMessage(_c, 0, m);
  cMsg_ZEsqiNqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CNzbk27o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_4vCIatMB_sendMessage(_c, 0, m);
  cMsg_r1y85jeE_sendMessage(_c, 0, m);
  cMsg_7of6Kna6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_2fyRLJIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_UDFqajRE_sendMessage(_c, 0, m);
  cMsg_JBO8v7jn_sendMessage(_c, 0, m);
  cMsg_w32cCMDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DCdLwQhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_4vCIatMB_sendMessage(_c, 0, m);
  cMsg_tVNfKM6i_sendMessage(_c, 0, m);
  cMsg_ZEsqiNqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_9q1vISqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lxVVB2lT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_DgmLMAxs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mFCybzCO, 0, m, &cSlice_mFCybzCO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BIZDolAb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_mFCybzCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ao1LQwgv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ao1LQwgv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_o02SDF25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ao1LQwgv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Ao1LQwgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_85lRXceF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_xGDt4ZoL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9Rf1i4RH, 0, m, &cSlice_9Rf1i4RH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_s3Mbol1W_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_9Rf1i4RH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jWsBMuUW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jWsBMuUW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_sqJyWLnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jWsBMuUW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_jWsBMuUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PpDpiPfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_s3Mbol1W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5R8H2iTJ, 0, m, &cSlice_5R8H2iTJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DgmLMAxs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_5R8H2iTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DCNSz3w0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DCNSz3w0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_MbuRkZgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DCNSz3w0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_DCNSz3w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_knFxVZcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_BIZDolAb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0UzxvfV8, 0, m, &cSlice_0UzxvfV8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mjC8arcR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_0UzxvfV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gmxTsST2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gmxTsST2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_cBXzkei5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gmxTsST2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_gmxTsST2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HdLDbw1M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_mjC8arcR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k8iYyJkT, 0, m, &cSlice_k8iYyJkT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dfzyOMYn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_k8iYyJkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AXEINTi2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AXEINTi2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_RLKvMPDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AXEINTi2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_AXEINTi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1bGDn5Y1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Zg0sQn2R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dcgbm1DK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dcgbm1DK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UFk7OQCd, 1, m, &cDelay_UFk7OQCd_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1i0ErzvC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_UFk7OQCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UFk7OQCd, m);
  cMsg_WNsWUD7H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_dcgbm1DK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UFk7OQCd, 0, m, &cDelay_UFk7OQCd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1i0ErzvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UFk7OQCd, 0, m, &cDelay_UFk7OQCd_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_nYNuWklT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PGPSR4UE, HV_BINOP_SUBTRACT, 0, m, &cBinop_PGPSR4UE_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_FVOTqAue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qBApebYU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_JlbDpeBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qBApebYU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_Tvie4yfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nYNuWklT, 0, m, &cVar_nYNuWklT_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_mld1hSEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T45ZxTBg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MApMejKr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nLL48RNn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PGPSR4UE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TYIuSIjm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_TYIuSIjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_15H7rQQU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_15H7rQQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DqMeSN4j_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_bqanuWQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KQo8RWB1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eIMQ4UEr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eIMQ4UEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CkiM6mNb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_KQo8RWB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FVOTqAue, 1, m, &cIf_FVOTqAue_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_H6c9QfqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JlbDpeBV, 1, m, &cIf_JlbDpeBV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CkiM6mNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FVOTqAue, 0, m, &cIf_FVOTqAue_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DqMeSN4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JlbDpeBV, 0, m, &cIf_JlbDpeBV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T45ZxTBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_nLL48RNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nYNuWklT, 0, m, &cVar_nYNuWklT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MApMejKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PGPSR4UE, HV_BINOP_SUBTRACT, 1, m, &cBinop_PGPSR4UE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qBApebYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_22iVh5e9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_dfzyOMYn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_via48rDx, 0, m, &cSlice_via48rDx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_via48rDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BAN8UeLT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BAN8UeLT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_tOAfw3pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BAN8UeLT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_BAN8UeLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UbS9DjyP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_O0D4JO2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xy5dMG1p, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_bJEFHdR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tTbunIRC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_dCarOo9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l5IG4b19, 0, m, &cVar_l5IG4b19_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lxVVB2lT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tv70G0mE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OgP0Wn3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Zg0sQn2R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_v4RGNZ9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IkFp6nu2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WNsWUD7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wugx4BHv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_IkFp6nu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wugx4BHv, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_uw7aDlgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_U8CKdIcI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_U8CKdIcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kPQ8jsKL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_kPQ8jsKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_86zybW2T, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_0lnzTmgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AjIZB3yA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qfivXNq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wOPXsQjY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ybtthN8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IuqT7Dzl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_ApJsM8LP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HDMLS65V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ortsobrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_97A4sH9I_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xGDt4ZoL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BcHgdzb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_97A4sH9I_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xGDt4ZoL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_SBWdaval_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vkTQMxFl, 0, m, &cVar_vkTQMxFl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_W31QjjCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_97A4sH9I_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xGDt4ZoL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iTTHGR1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_97A4sH9I_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xGDt4ZoL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_K2HvwISw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_97A4sH9I_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xGDt4ZoL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9eG2hl5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_VcwyiKDl, 0, m, &cVar_VcwyiKDl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XCD5N96f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_vSL6FdVZ, 0, m, &cVar_vSL6FdVZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bhsbnf00, 0, m, &cVar_bhsbnf00_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1GQNTgRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SBWdaval_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_e5m5z5pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_XIAIrOA8, 0, m, &cVar_XIAIrOA8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AjIZB3yA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_97A4sH9I_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_xGDt4ZoL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xAiJ7SPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_0lnzTmgD, 0, m, &cVar_0lnzTmgD_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_HDMLS65V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AoApYenF_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_hk3aMEWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FILEER27, 0, m, &cVar_FILEER27_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_grDDEPIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SBWdaval_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_q5H7kLLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VcwyiKDl, 0, m, &cVar_VcwyiKDl_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_pPBqkwW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_floQ4aih, 0, m, &cVar_floQ4aih_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nh2AXAfL, 0, m, &cVar_nh2AXAfL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kqYlqubX, 0, m, &cVar_kqYlqubX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_alO1u5Wb, 0, m, &cVar_alO1u5Wb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PQ5FoBOa, 0, m, &cVar_PQ5FoBOa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jvA5t7fD, 0, m, &cVar_jvA5t7fD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o02SDF25, 0, m, &cVar_o02SDF25_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sqJyWLnc, 0, m, &cVar_sqJyWLnc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MbuRkZgG, 0, m, &cVar_MbuRkZgG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cBXzkei5, 0, m, &cVar_cBXzkei5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RLKvMPDk, 0, m, &cVar_RLKvMPDk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tOAfw3pF, 0, m, &cVar_tOAfw3pF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KziU9c65_sendMessage);
  cMsg_e5m5z5pb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_83KrHcjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XIAIrOA8, 0, m, &cVar_XIAIrOA8_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ej10agL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vSL6FdVZ, 0, m, &cVar_vSL6FdVZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ONynpHoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bhsbnf00, 0, m, &cVar_bhsbnf00_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_xBn5amjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZzTkccK7, 0, m, &cVar_ZzTkccK7_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_JGTzcU4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_v1B6ORfG, 0, m, &cVar_v1B6ORfG_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_BYdby8Lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_u7WFN1SU_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_LtJrdcA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ndqJPa5s_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_okzJ7MOj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wqBb2iQC_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_aEwB1SCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aVfpPkbI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QrmtKUA4_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_tMRU8C6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RImxlzrj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_85lRXceF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IAsubOND, 0, m, &cVar_IAsubOND_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_HdLDbw1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9q1vISqU, 0, m, &cVar_9q1vISqU_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_knFxVZcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_dCarOo9V_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_PpDpiPfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uweHJMOc_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v4RGNZ9F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OgP0Wn3O_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_1bGDn5Y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bqanuWQX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_H6c9QfqD_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_UbS9DjyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uw7aDlgs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_4RwcJkzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0lnzTmgD, 0, m, &cVar_0lnzTmgD_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_VlEFe1js, VIf(I0));
    __hv_varread_f(&sVarf_TacSYhKK, VOf(Bf0));
    __hv_varread_f(&sVarf_SOfePqhU, VOf(Bf1));
    __hv_varread_f(&sVarf_GQEFa04T, VOf(Bf2));
    __hv_varread_f(&sVarf_p1VhzomV, VOf(Bf3));
    __hv_varread_f(&sVarf_BkRz0grt, VOf(Bf4));
    __hv_varread_f(&sVarf_i4ZBAD10, VOf(Bf5));
    __hv_varread_f(&sVarf_kw1S0cir, VOf(Bf6));
    __hv_varwrite_f(&sVarf_o3oneHDx, VIf(I0));
    __hv_varread_f(&sVarf_X5I32A2r, VOf(Bf7));
    __hv_line_f(&sLine_wmCOcu6S, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_awv28CFY, VOf(Bf9));
    __hv_line_f(&sLine_G6ZbzoK3, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_XmPQ737y, VOf(Bf8));
    __hv_line_f(&sLine_G8OmWKmD, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_p1VhzomV, VIf(Bf11));
    __hv_varread_f(&sVarf_o3oneHDx, VOf(Bf11));
    __hv_line_f(&sLine_JYf4Hmbi, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_Kwgbw6KV, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_ZpME6rU0, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_BkRz0grt, VIf(Bf10));
    __hv_line_f(&sLine_xt9dHIij, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_Hp07ruxp, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_yaVQ2JfC, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_i4ZBAD10, VIf(Bf10));
    __hv_line_f(&sLine_yx3HknVq, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_fYr3WKsE, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_lWXtAXxY, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_kw1S0cir, VIf(Bf10));
    __hv_varwrite_f(&sVarf_X5I32A2r, VIf(Bf0));
    __hv_varwrite_f(&sVarf_awv28CFY, VIf(Bf1));
    __hv_varwrite_f(&sVarf_XmPQ737y, VIf(Bf2));
    sEnv_process(this, &sEnv_JDwHNMNY, VIf(Bf3), &sEnv_JDwHNMNY_sendMessage);
    sEnv_process(this, &sEnv_VRKADSu0, VIf(I0), &sEnv_VRKADSu0_sendMessage);
    __hv_line_f(&sLine_FcCM9BTc, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_GDW0FGeo, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_UpQ2PGnF, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_aprOSxP5, VOf(Bf3));
    __hv_line_f(&sLine_ycdSuMC9, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_TacSYhKK, VIf(Bf0));
    __hv_varwrite_f(&sVarf_aprOSxP5, VIf(Bf4));
    __hv_varwrite_f(&sVarf_RnXA957c, VIf(Bf5));
    __hv_varwrite_f(&sVarf_45NEmqCM, VIf(Bf6));
    __hv_varread_f(&sVarf_45NEmqCM, VOf(Bf6));
    __hv_line_f(&sLine_3vD6CxH1, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_GQEFa04T, VIf(Bf4));
    __hv_varread_f(&sVarf_RnXA957c, VOf(Bf4));
    __hv_line_f(&sLine_pWEMR9Yu, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_SOfePqhU, VIf(Bf4));
    __hv_varwrite_f(&sVarf_zuNkJuKm, VIf(Bf2));
    __hv_varwrite_f(&sVarf_RhrlLAm7, VIf(I1));
    __hv_varread_f(&sVarf_S3AkB2RD, VOf(Bf2));
    __hv_varread_f(&sVarf_Hai6c2bq, VOf(Bf4));
    __hv_varread_f(&sVarf_bMmlPSJI, VOf(Bf0));
    __hv_varread_f(&sVarf_nAtyG6mw, VOf(Bf5));
    __hv_varread_f(&sVarf_cD94kfdg, VOf(Bf3));
    __hv_varread_f(&sVarf_kEnnEvKk, VOf(Bf6));
    __hv_varread_f(&sVarf_5eaTzBVA, VOf(Bf1));
    __hv_varwrite_f(&sVarf_DynOA7fD, VIf(I1));
    __hv_varread_f(&sVarf_RYj0ub4c, VOf(Bf10));
    __hv_line_f(&sLine_0s2MJz6j, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_rm9RCCfZ, VOf(Bf7));
    __hv_line_f(&sLine_cKLaweRP, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_UDzmW5bE, VOf(Bf11));
    __hv_line_f(&sLine_zbiQHFsm, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_nAtyG6mw, VIf(Bf12));
    __hv_varread_f(&sVarf_DynOA7fD, VOf(Bf12));
    __hv_line_f(&sLine_bJfmdZuE, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_FbvuMgEX, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_1XwUNFHx, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_cD94kfdg, VIf(Bf9));
    __hv_line_f(&sLine_J0SMxXkp, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_O0aeQBam, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_OdotmxdX, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_kEnnEvKk, VIf(Bf9));
    __hv_line_f(&sLine_5kFFWOvk, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_s1jJJEFI, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_rME2ynHy, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_5eaTzBVA, VIf(Bf9));
    __hv_varwrite_f(&sVarf_RYj0ub4c, VIf(Bf2));
    __hv_varwrite_f(&sVarf_rm9RCCfZ, VIf(Bf4));
    __hv_varwrite_f(&sVarf_UDzmW5bE, VIf(Bf0));
    sEnv_process(this, &sEnv_Tvie4yfg, VIf(Bf5), &sEnv_Tvie4yfg_sendMessage);
    sEnv_process(this, &sEnv_mld1hSEg, VIf(I1), &sEnv_mld1hSEg_sendMessage);
    __hv_line_f(&sLine_22iVh5e9, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Wugx4BHv, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_86zybW2T, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_yZuo3UrK, VOf(Bf5));
    __hv_line_f(&sLine_tTbunIRC, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_S3AkB2RD, VIf(Bf2));
    __hv_varwrite_f(&sVarf_yZuo3UrK, VIf(Bf3));
    __hv_varwrite_f(&sVarf_M8Al2XO4, VIf(Bf6));
    __hv_varwrite_f(&sVarf_GkdFrnHa, VIf(Bf1));
    __hv_varread_f(&sVarf_GkdFrnHa, VOf(Bf1));
    __hv_line_f(&sLine_Tv70G0mE, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_bMmlPSJI, VIf(Bf3));
    __hv_varread_f(&sVarf_M8Al2XO4, VOf(Bf3));
    __hv_line_f(&sLine_xy5dMG1p, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_Hai6c2bq, VIf(Bf3));
    __hv_varwrite_f(&sVarf_1n2B06fd, VIf(Bf0));
    __hv_varread_f(&sVarf_RhrlLAm7, VOf(Bf0));
    __hv_line_f(&sLine_IuqT7Dzl, VOf(Bf3));
    __hv_varread_f(&sVarf_1n2B06fd, VOf(Bf2));
    __hv_line_f(&sLine_wOPXsQjY, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_VlEFe1js, VOf(Bf2));
    __hv_varread_f(&sVarf_zuNkJuKm, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
